@@ -1,6 +1,6 @@
 #Splitting out maringal effects to see if they can be generalized
 
-from statsmodels.compat.python import lzip, range
+from statsmodels.compat.python import lzip
 import numpy as np
 from scipy.stats import norm
 from statsmodels.tools.decorators import cache_readonly
@@ -45,7 +45,7 @@ def _isdummy(X):
 
     Parameters
     ----------
-    X : array-like
+    X : array_like
         A 1d or 2d array of numbers
 
     Examples
@@ -71,7 +71,7 @@ def _get_dummy_index(X, const_idx):
     dummy_ind = _isdummy(X)
     dummy = True
 
-    if dummy_ind.size == 0: # don't waste your time
+    if dummy_ind.size == 0: # do not waste your time
         dummy = False
         dummy_ind = None # this gets passed to stand err func
     return dummy_ind, dummy
@@ -82,7 +82,7 @@ def _iscount(X):
 
     Parameters
     ----------
-    X : array-like
+    X : array_like
         A 1d or 2d array of numbers
 
     Examples
@@ -106,7 +106,7 @@ def _get_count_index(X, const_idx):
     count_ind = _iscount(X)
     count = True
 
-    if count_ind.size == 0: # don't waste your time
+    if count_ind.size == 0: # do not waste your time
         count = False
         count_ind = None # for stand err func
     return count_ind, count
@@ -152,7 +152,7 @@ def _get_count_effects(effects, exog, count_ind, method, model, params):
         exog0[:, i] += 2
         effect1 = model.predict(params, exog0)
         #NOTE: done by analogy with dummy effects but untested bc
-        # stata doesn't handle both count and eydx anywhere
+        # stata does not handle both count and eydx anywhere
         if 'ey' in method:
             effect0 = np.log(effect0)
             effect1 = np.log(effect1)
@@ -263,11 +263,11 @@ def margeff_cov_params(model, params, exog, cov_params, at, derivative,
         The model that returned the fitted results. Its pdf method is used
         for computing the Jacobian of discrete variables in dummy_ind and
         count_ind
-    params : array-like
+    params : array_like
         estimated model parameters
-    exog : array-like
+    exog : array_like
         exogenous variables at which to calculate the derivative
-    cov_params : array-like
+    cov_params : array_like
         The variance-covariance of the parameters
     at : str
        Options are:
@@ -281,15 +281,15 @@ def margeff_cov_params(model, params, exog, cov_params, at, derivative,
 
         Only overall has any effect here.you
 
-    derivative : function or array-like
+    derivative : function or array_like
         If a function, it returns the marginal effects of the model with
         respect to the exogenous variables evaluated at exog. Expected to be
         called derivative(params, exog). This will be numerically
         differentiated. Otherwise, it can be the Jacobian of the marginal
         effects with respect to the parameters.
-    dummy_ind : array-like
+    dummy_ind : array_like
         Indices of the columns of exog that contain dummy variables
-    count_ind : array-like
+    count_ind : array_like
         Indices of the columns of exog that contain count variables
 
     Notes
@@ -309,7 +309,7 @@ def margeff_cov_params(model, params, exog, cov_params, at, derivative,
         try:
             jacobian_mat = approx_fprime_cs(params, derivative,
                                             args=(exog,method))
-        except TypeError:  # norm.cdf doesn't take complex values
+        except TypeError:  # norm.cdf does not take complex values
             from statsmodels.tools.numdiff import approx_fprime
             jacobian_mat = approx_fprime(params, derivative,
                                             args=(exog,method))
@@ -326,7 +326,7 @@ def margeff_cov_params(model, params, exog, cov_params, at, derivative,
     else:
         jacobian_mat = derivative
 
-    #NOTE: this won't go through for at == 'all'
+    #NOTE: this will not go through for at == 'all'
     return np.dot(np.dot(jacobian_mat, cov_params), jacobian_mat.T)
 
 def margeff_cov_with_se(model, params, exog, cov_params, at, derivative,
@@ -626,14 +626,14 @@ class DiscreteMargins(object):
               are returned.  This is the default.
             - 'eyex' - estimate elasticities of variables in `exog` --
               d(lny)/d(lnx)
-            - 'dyex' - estimate semielasticity -- dy/d(lnx)
-            - 'eydx' - estimate semeilasticity -- d(lny)/dx
+            - 'dyex' - estimate semi-elasticity -- dy/d(lnx)
+            - 'eydx' - estimate semi-elasticity -- d(lny)/dx
 
             Note that tranformations are done after each observation is
             calculated.  Semi-elasticities for binary variables are computed
             using the midpoint method. 'dyex' and 'eyex' do not make sense
             for discrete variables.
-        atexog : array-like, optional
+        atexog : array_like, optional
             Optionally, you can provide the exogenous variables over which to
             get the marginal effects.  This should be a dictionary with the key
             as the zero-indexed column number and the value of the dictionary.
@@ -725,7 +725,7 @@ class DiscreteMargins(object):
                                                                   order='F')
                 self.margeff_cov = margeff_cov[effects_idx][:, effects_idx]
             else:
-                # don't care about at constant
+                # do not care about at constant
                 # hack truncate effects_idx again if necessary
                 # if eyex, then effects is truncated to be without extra params
                 effects_idx = effects_idx[:len(effects)]
